@@ -31,7 +31,10 @@ class Client(Singleton):
         client = Client(host, redis_client, mq_manager, async_mq_mode, init_redis=init_redis)
         return client
     
-    def __init__(self, host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None, init_redis=init_redis) -> None:
+    def __init__(self, host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None, init_redis=True) -> None:
+        if not self.need_init():
+            return
+        
         self.host = host
         if redis_client is None and init_redis:
             redis_client = XRedis(REDIS['host'], REDIS['pass'], REDIS['port'], REDIS['db'])
@@ -55,6 +58,7 @@ class Client(Singleton):
         self.get_topic = 'fs_get'
         
         self.update()
+        self._inited = True
     
     def update(self):
         with self.lock:
